==> nextcloud-22.2.9.tgz: nextcloud/apps/survey_client/l10n/pl.js <==
OC.L10N.register(
    "survey_client",
    {
    "Last report sent on: {on}" : "Ostatni raport wysłano: {on}",
    "An error occurred while sending your report." : "Wystąpił błąd podczas wysyłania raportu.",
    "App list <em>(for each app: name, version, enabled status)</em>" : "Lista aplikacji <em>(dla każdej: nazwa, wersja, stan włączenia)</em>",
    "Database environment <em>(type, version, database size)</em>" : "Środowisko bazy danych <em>(typ, wersja, rozmiar)</em>",
    "Encryption information <em>(is it enabled?, what is the default module)</em>" : "Informacje o szyfrowaniu <em>(czy jest włączone?, jaki jest domyślny moduł)</em>",
    "Number of shares <em>(per type and permission setting)</em>" : "Liczba udostępnień <em>(według typu i ustawienia uprawnień)</em>",
    "PHP environment <em>(version, memory limit, max. execution time, max. file size)</em>" : "Środowisko PHP <em>(wersja, limit pamięci, maks. czas wykonania, maks. rozmiar pliku)</em>",
    "Server instance details <em>(version, memcache used, status of locking/previews/avatars)</em>" : "Szczegóły serwera <em>(wersja, użyta pamięć, status blokad/podglądów/awatarów)</em>",
    "Statistic <em>(number of files, users, storages per type, comments and tags)</em>" : "Statystyki <em>(liczba: plików, użytkowników, typów pamięci, komentarzy oraz etykiet)</em>",
    "Usage survey" : "Raport użytkowania",
    "Help improve Nextcloud" : "Pomóż ulepszyć Nextcloud",
    "Do you want to help us to improve Nextcloud by providing some anonymized data about your setup and usage? You can disable it at any time in the admin settings again." : "Czy chcesz pomóc nam ulepszyć Nextcloud, dostarczając anonimowych danych na temat konfiguracji i użytkowania? W każdej chwili będziesz mógł je wyłączyć w panelu administratora.",
    "Not now" : "Nie teraz",
    "Send usage" : "Wyślij raport",
    "Never" : "Nigdy",
    "Sends anonymized data to Nextcloud to help us to improve Nextcloud." : "Wysyła anonimowe dane, aby pomóc nam ulepszyć Nextcloud.",
    "Sends anonymized data to Nextcloud to help us to improve Nextcloud. You\n\t\talways have full control over the content sent to Nextcloud and can disable\n\t\tit again at any time." : "Wysyła anonimowe dane do Nextcloud, aby pomóc nam ulepszyć Nextcloud. Zawsze masz pełną kontrolę nad treścią przesyłaną do Nextcloud i możesz ją ponownie wyłączyć w dowolnym momencie.",
    "You can help improve Nextcloud by sending us some data about your current setup and usage." : "Możesz pomóc w ulepszeniu Nextcloud, wysyłając nam trochę danych na temat bieżącej konfiguracji i użytkowania.",
    "We take your privacy seriously. Sending data is disabled by default, and should you choose to turn it on, it will be anonymized first, and you are given the option of what things to share. Upon receiving a report, the previous one is removed. Upload a clean report to delete all data currently stored on the server" : "Poważnie traktujemy Twoją prywatność. Wysyłanie danych jest domyślnie wyłączone, ale jeśli zdecydujesz się je włączyć, najpierw zostaną one zanonimizowane, a Ty będziesz miał możliwość wyboru, co chcesz udostępniać. Po otrzymaniu raportu poprzedni jest usuwany. Prześlij czysty raport, aby usunąć wszystkie dane aktualnie przechowywane na serwerze.",
    "Send new report now" : "Wyślij nowy raport",
    "Send usage survey monthly" : "Wysyłaj raport co miesiąc",
    "Data to send" : "Dane do wysłania",
    "Last report sent on: %s" : "Ostatni raport wysłano: %s",
    "Last report" : "Ostatni raport",
    "Sends anonymized data to Nextcloud to help us to improve Nextcloud. You\n        always have full control over the content sent to Nextcloud and can disable\n        it again at any time." : "Wysyła anonimowe dane do Nextcloud, aby pomóc nam w jego ulepszaniu. Zawsze\n        masz pełną kontrolę nad tym, co jest wysyłane do Nextcloud i możesz wyłączyć\n        przesyłanie w dowolnym momencie."
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");

==> nextcloud-23.0.9.tgz: nextcloud/apps/survey_client/l10n/pl.js <==
OC.L10N.register(
    "survey_client",
    {
    "Last report sent on: {on}" : "Ostatni raport wysłano: {on}",
    "An error occurred while sending your report." : "Wystąpił błąd podczas wysyłania raportu.",
    "App list <em>(for each app: name, version, enabled status)</em>" : "Lista aplikacji <em>(dla każdej: nazwa, wersja, stan włączenia)</em>",
    "Database environment <em>(type, version, database size)</em>" : "Środowisko bazy danych <em>(typ, wersja, rozmiar)</em>",
    "Encryption information <em>(is it enabled?, what is the default module)</em>" : "Informacje o szyfrowaniu <em>(czy jest włączone?, jaki jest domyślny moduł)</em>",
    "Number of shares <em>(per type and permission setting)</em>" : "Liczba udostępnień <em>(według typu i ustawienia uprawnień)</em>",
    "PHP environment <em>(version, memory limit, max. execution time, max. file size)</em>" : "Środowisko PHP <em>(wersja, limit pamięci, maks. czas wykonania, maks. rozmiar pliku)</em>",
    "Server instance details <em>(version, memcache used, status of locking/previews/avatars)</em>" : "Szczegóły serwera <em>(wersja, użyta pamięć, status blokad/podglądów/awatarów)</em>",
    "Statistic <em>(number of files, users, storages per type, comments and tags)</em>" : "Statystyki <em>(liczba: plików, użytkowników, typów pamięci, komentarzy oraz etykiet)</em>",
    "Usage survey" : "Raport użytkowania",
    "Help improve Nextcloud" : "Pomóż ulepszyć Nextcloud",
    "Do you want to help us to improve Nextcloud by providing some anonymized data about your setup and usage? You can disable it at any time in the admin settings again." : "Czy chcesz pomóc nam ulepszyć Nextcloud, dostarczając anonimowe dane dotyczące Twojej konfiguracji i użytkowania? W każdej chwili będziesz mógł je wyłączyć w ustawieniach administratora.",
    "Not now" : "Nie teraz",
    "Send usage" : "Wyślij raport",
    "Never" : "Nigdy",
    "Sends anonymized data to Nextcloud to help us to improve Nextcloud." : "Wysyła anonimowe dane, aby pomóc nam ulepszyć Nextcloud.",
    "Sends anonymized data to Nextcloud to help us to improve Nextcloud. You\n\t\talways have full control over the content sent to Nextcloud and can disable\n\t\tit again at any time." : "Wysyła anonimowe dane do Nextcloud, aby pomóc nam ulepszyć Nextcloud. Zawsze masz pełną kontrolę nad treścią przesyłaną do Nextcloud i możesz ją ponownie wyłączyć w dowolnym momencie.",
    "You can help improve Nextcloud by sending us some data about your current setup and usage." : "Możesz pomóc w ulepszeniu Nextcloud, wysyłając nam trochę danych na temat bieżącej konfiguracji i użytkowania.",
    "We take your privacy seriously. Sending data is disabled by default, and should you choose to turn it on, it will be anonymized first, and you are given the option of what things to share. Upon receiving a report, the previous one is removed. Upload a clean report to delete all data currently stored on the server" : "Poważnie traktujemy Twoją prywatność. Wysyłanie danych jest domyślnie wyłączone, ale jeśli zdecydujesz się je włączyć, najpierw zostaną one zanonimizowane, a Ty będziesz miał możliwość wyboru, co chcesz udostępniać. Po otrzymaniu raportu poprzedni jest usuwany. Prześlij czysty raport, aby usunąć wszystkie dane aktualnie przechowywane na serwerze.",
    "Send new report now" : "Wyślij nowy raport",
    "Send usage survey monthly" : "Wysyłaj raport co miesiąc",
    "Data to send" : "Dane do wysłania",
    "Last report sent on: %s" : "Ostatni raport wysłano: %s",
    "Last report" : "Ostatni raport",
    "Sends anonymized data to Nextcloud to help us to improve Nextcloud. You\n        always have full control over the content sent to Nextcloud and can disable\n        it again at any time." : "Wysyła anonimowe dane do Nextcloud, aby pomóc nam w jego ulepszaniu. Zawsze\n        masz pełną kontrolę nad tym, co jest wysyłane do Nextcloud i możesz wyłączyć\n        przesyłanie w dowolnym momencie."
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
